@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -22,16 +21,16 @@
 ##############################################################################
 
 from trytond.pool import Pool
-from .health_icu import *
+from . import health_icu
 
 
 def register():
     Pool.register(
-        InpatientRegistration,
-        InpatientIcu,
-        Glasgow,
-        ApacheII,
-        MechanicalVentilation,
-        ChestDrainageAssessment,
-        PatientRounding,
+        health_icu.InpatientRegistration,
+        health_icu.InpatientIcu,
+        health_icu.Glasgow,
+        health_icu.ApacheII,
+        health_icu.MechanicalVentilation,
+        health_icu.ChestDrainageAssessment,
+        health_icu.PatientRounding,
         module='health_icu', type_='model')
