@@ -26,7 +26,9 @@ from trytond.wizard import Wizard
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 from trytond.i18n import gettext
-from ..exceptions import (ServiceInvoiced, NoInvoiceAddress, NoPaymentTerm)
+from trytond.modules.product import round_price
+from ..exceptions import (
+    ServiceInvoiced, NoInvoiceAddress, NoPaymentTerm, NoAccountReceivable)
 
 __all__ = ['CreateServiceInvoice']
 
@@ -71,6 +73,8 @@ class CreateServiceInvoice(Wizard):
         Invoice = pool.get('account.invoice')
         Party = pool.get('party.party')
         Journal = pool.get('account.journal')
+        AcctConfig = pool.get('account.configuration')
+        acct_config = AcctConfig(1)
 
         currency_id = Transaction().context.get('currency')
 
@@ -93,9 +97,22 @@ class CreateServiceInvoice(Wizard):
             invoice_data['party'] = party.id
             invoice_data['type'] = 'out'
             invoice_data['invoice_date'] = datetime.date.today()
-            invoice_data['account'] = party.account_receivable.id
             invoice_data['company'] = service.company.id
 
+            """ Look for the AR account in the following order:
+                * Party
+                * Default AR in accounting config
+                * Raise an error if there is no AR account
+            """
+            if (party.account_receivable):
+                invoice_data['account'] = party.account_receivable.id
+            elif (acct_config.default_account_receivable):
+                invoice_data['account'] = \
+                    acct_config.default_account_receivable.id
+            else:
+                raise NoAccountReceivable(
+                    gettext('health_insurance.msg_no_account_receivable'))
+
             ctx = {}
             sale_price_list = None
             if hasattr(party, 'sale_price_list'):
@@ -127,13 +144,21 @@ class CreateServiceInvoice(Wizard):
             invoice_data['invoice_address'] = party_address.id
             invoice_data['reference'] = service.name
 
-            if not party.customer_payment_term:
+            """ Look for the payment term in the following order:
+                * Party
+                * Default payment term in accounting config
+                * Raise an error if there is no payment term
+            """
+            if (party.customer_payment_term):
+                invoice_data['payment_term'] = party.customer_payment_term.id
+            elif (acct_config.default_customer_payment_term):
+                invoice_data['payment_term'] = \
+                    acct_config.default_customer_payment_term.id
+            else:
                 raise NoPaymentTerm(
                     gettext('health_insurance.msg_no_payment_term')
                     )
 
-            invoice_data['payment_term'] = party.customer_payment_term.id
-
             # Invoice Lines
             seq = 0
             invoice_lines = []
@@ -168,9 +193,12 @@ class CreateServiceInvoice(Wizard):
                             if 'value' in list(discount.keys()):
                                 if discount['value']:
                                     if (discount['type'] == 'pct'):
-                                        unit_price *= (
-                                            1 - decimal.Decimal(
-                                                discount['value'])/100)
+                                        unit_price *= decimal.Decimal(
+                                            1 - discount['value']/100)
+                                        # Use price_decimal value from
+                                        # system configuration to set
+                                        # the number of decimals
+                                        unit_price = round_price(unit_price)
 
                                         # Add remark on description discount
                                         str_disc = str(discount['value']) + '%'
